==> v1.0.0.20180119_beta.zip: fastadmin/application/index/lang/zh-cn.php <==
<?php

return [
    'Keep login'                                             => '保持会话',
    'Forgot password'                                        => '忘记密码?',
    'Sign in'                                                => '登入',
    'Username'                                               => '用户名',
    'User id'                                                => '会员ID',
    'Username'                                               => '用户名',
    'Nickname'                                               => '昵称',
    'Password'                                               => '密码',
    'Sign up'                                                => '注 册',
    'Sign in'                                                => '登 录',
    'Sign out'                                               => '注 销',
    'Guest'                                                  => '游客',
    'Welcome'                                                => '%s，你好！',
    'Add'                                                    => '添加',
    'Edit'                                                   => '编辑',
    'Delete'                                                 => '删除',
    'Move'                                                   => '移动',
    'Name'                                                   => '名称',
    'Status'                                                 => '状态',
    'Weigh'                                                  => '权重',
    'Operate'                                                => '操作',
    'Warning'                                                => '温馨提示',
    'Default'                                                => '默认',
    'Article'                                                => '文章',
    'Page'                                                   => '单页',
    'OK'                                                     => '确定',
    'Cancel'                                                 => '取消',
    'Loading'                                                => '加载中',
    'More'                                                   => '更多',
    'Normal'                                                 => '正常',
    'Hidden'                                                 => '隐藏',
    'Submit'                                                 => '提交',
    'Reset'                                                  => '重置',
    'Execute'                                                => '执行',
    'Close'                                                  => '关闭',
    'Search'                                                 => '搜索',
    'Refresh'                                                => '刷新',
    'First'                                                  => '首页',
    'Previous'                                               => '上一页',
    'Next'                                                   => '下一页',
    'Last'                                                   => '末页',
    'None'                                                   => '无',
    'Home'                                                   => '主页',
    'Online'                                                 => '在线',
    'Logout'                                                 => '注销',
    'Profile'                                                => '个人资料',
    'Index'                                                  => '首页',
    'Hot'                                                    => '热门',
    'Recommend'                                              => '推荐',
    'Dashboard'                                              => '控制台',
    'Code'                                                   => '编号',
    'Message'                                                => '内容',
    'Line'                                                   => '行号',
    'File'                                                   => '文件',
    'Menu'                                                   => '菜单',
    'Name'                                                   => '名称',
    'Weigh'                                                  => '权重',
    'Type'                                                   => '类型',
    'Title'                                                  => '标题',
    'Content'                                                => '内容',
    'Status'                                                 => '状态',
    'Operate'                                                => '操作',
    'Append'                                                 => '追加',
    'Memo'                                                   => '备注',
    'Parent'                                                 => '父级',
    'Params'                                                 => '参数',
    'Permission'                                             => '权限',
    'Advance search'                                         => '高级搜索',
    'Check all'                                              => '选中全部',
    'Expand all'                                             => '展开全部',
    'Begin time'                                             => '开始时间',
    'End time'                                               => '结束时间',
    'Create time'                                            => '创建时间',
    'Flag'                                                   => '标志',
    'Gitee'                                                  => '码云',
    'Github'                                                 => 'Github',
    'QQ group'                                               => 'QQ群',
    'Go to Dashboard'                                        => '登录后台',
    'Contribution'                                           => '为FastAdmin贡献代码!',
    'Copyrights'                                             => '版权所有',
    'Responsive'                                             => '响应式开发',
    'Languages'                                              => '多语言',
    'Module'                                                 => '模块化开发',
    'Extension'                                              => '自由可扩展',
    'Auth'                                                   => '权限管理',
    'The fastest framework based on ThinkPHP5 and Bootstrap' => '基于ThinkPHP5和Bootstrap的极速后台开发框架',
    'Features'                                               => '功能特性',
    'Home'                                                   => '首页',
    'Store'                                                  => '插件市场',
    'Services'                                               => '服务',
    'Download'                                               => '下载',
    'Demo'                                                   => '演示',
    'Donation'                                               => '捐赠',
    'Forum'                                                  => '社区',
    'Docs'                                                   => '文档',
    'Send verification code'                                 => '发磅验证码',
    'Redirect now'                                           => '立即跳转',
    'Operation completed'                                    => '操作成功!',
    'Operation failed'                                       => '操作失败!',
    'Unknown data format'                                    => '未知的数据格式!',
    'Network error'                                          => '网络错误!',
    'Advanced search'                                        => '高级搜索',
    'Invalid parameters'                                     => '未知参数',
    'No results were found'                                  => '记录未找到',
    'Parameter %s can not be empty'                          => '参数%s不能为空',
    'You have no permission'                                 => '你没有权限访问',
    'An unexpected error occurred'                           => '发生了一个意外错误,程序猿正在紧急处理中',
    'This page will be re-directed in %s seconds'            => '页面将在 %s 秒后自动跳转',
];

==> v1.0.0.20180308_beta.zip: fastadmin/application/index/lang/zh-cn.php <==
<?php

return [
    'Keep login'                                             => '保持会话',
    'Forgot password'                                        => '忘记密码?',
    'Sign in'                                                => '登入',
    'Username'                                               => '用户名',
    'User id'                                                => '会员ID',
    'Username'                                               => '用户名',
    'Nickname'                                               => '昵称',
    'Password'                                               => '密码',
    'Sign up'                                                => '注 册',
    'Sign in'                                                => '登 录',
    'Sign out'                                               => '注 销',
    'Guest'                                                  => '游客',
    'Welcome'                                                => '%s，你好！',
    'Add'                                                    => '添加',
    'Edit'                                                   => '编辑',
    'Delete'                                                 => '删除',
    'Move'                                                   => '移动',
    'Name'                                                   => '名称',
    'Status'                                                 => '状态',
    'Weigh'                                                  => '权重',
    'Operate'                                                => '操作',
    'Warning'                                                => '温馨提示',
    'Default'                                                => '默认',
    'Article'                                                => '文章',
    'Page'                                                   => '单页',
    'OK'                                                     => '确定',
    'Cancel'                                                 => '取消',
    'Loading'                                                => '加载中',
    'More'                                                   => '更多',
    'Normal'                                                 => '正常',
    'Hidden'                                                 => '隐藏',
    'Submit'                                                 => '提交',
    'Reset'                                                  => '重置',
    'Execute'                                                => '执行',
    'Close'                                                  => '关闭',
    'Search'                                                 => '搜索',
    'Refresh'                                                => '刷新',
    'First'                                                  => '首页',
    'Previous'                                               => '上一页',
    'Next'                                                   => '下一页',
    'Last'                                                   => '末页',
    'None'                                                   => '无',
    'Home'                                                   => '主页',
    'Online'                                                 => '在线',
    'Logout'                                                 => '注销',
    'Profile'                                                => '个人资料',
    'Index'                                                  => '首页',
    'Hot'                                                    => '热门',
    'Recommend'                                              => '推荐',
    'Dashboard'                                              => '控制台',
    'Code'                                                   => '编号',
    'Message'                                                => '内容',
    'Line'                                                   => '行号',
    'File'                                                   => '文件',
    'Menu'                                                   => '菜单',
    'Name'                                                   => '名称',
    'Weigh'                                                  => '权重',
    'Type'                                                   => '类型',
    'Title'                                                  => '标题',
    'Content'                                                => '内容',
    'Status'                                                 => '状态',
    'Operate'                                                => '操作',
    'Append'                                                 => '追加',
    'Memo'                                                   => '备注',
    'Parent'                                                 => '父级',
    'Params'                                                 => '参数',
    'Permission'                                             => '权限',
    'Advance search'                                         => '高级搜索',
    'Check all'                                              => '选中全部',
    'Expand all'                                             => '展开全部',
    'Begin time'                                             => '开始时间',
    'End time'                                               => '结束时间',
    'Create time'                                            => '创建时间',
    'Flag'                                                   => '标志',
    'Gitee'                                                  => '码云',
    'Github'                                                 => 'Github',
    'QQ group'                                               => 'QQ群',
    'Go to Dashboard'                                        => '登录后台',
    'Contribution'                                           => '为FastAdmin贡献代码!',
    'Copyrights'                                             => '版权所有',
    'Responsive'                                             => '响应式开发',
    'Languages'                                              => '多语言',
    'Module'                                                 => '模块化开发',
    'Extension'                                              => '自由可扩展',
    'Auth'                                                   => '权限管理',
    'The fastest framework based on ThinkPHP5 and Bootstrap' => '基于ThinkPHP5和Bootstrap的极速后台开发框架',
    'Features'                                               => '功能特性',
    'Home'                                                   => '首页',
    'Store'                                                  => '插件市场',
    'Services'                                               => '服务',
    'Download'                                               => '下载',
    'Demo'                                                   => '演示',
    'Donation'                                               => '捐赠',
    'Forum'                                                  => '社区',
    'Docs'                                                   => '文档',
    'Please login first'                                     => '请登录后再操作',
    'Send verification code'                                 => '发送验证码',
    'Redirect now'                                           => '立即跳转',
    'Operation completed'                                    => '操作成功!',
    'Operation failed'                                       => '操作失败!',
    'Unknown data format'                                    => '未知的数据格式!',
    'Network error'                                          => '网络错误!',
    'Advanced search'                                        => '高级搜索',
    'Invalid parameters'                                     => '未知参数',
    'No results were found'                                  => '记录未找到',
    'Parameter %s can not be empty'                          => '参数%s不能为空',
    'You have no permission'                                 => '你没有权限访问',
    'An unexpected error occurred'                           => '发生了一个意外错误,程序猿正在紧急处理中',
    'This page will be re-directed in %s seconds'            => '页面将在 %s 秒后自动跳转',
];
